==> posh-nb-support-3.2.0-20110228.161656-4-sources.jar: cz/cuni/pogamut/posh/widget/accept/AcceptSense2Sense.java <==
package cz.cuni.pogamut.posh.widget.accept;

import cz.cuni.amis.pogamut.sposh.elements.CompetenceElement;
import cz.cuni.amis.pogamut.sposh.elements.Goal;
import cz.cuni.amis.pogamut.sposh.elements.PoshElement;
import cz.cuni.amis.pogamut.sposh.elements.Sense;
import cz.cuni.amis.pogamut.sposh.elements.Triggers;
import java.awt.datatransfer.Transferable;
import java.awt.datatransfer.UnsupportedFlavorException;
import java.io.IOException;

/**
 * When sense is dropped on the sense, add it to the list on the place
 * where passed poshsense was and move the rest of list down.
 * @author Honza
 */
public class AcceptSense2Sense extends AbstractAcceptAction<Sense> {

    public AcceptSense2Sense(Sense dataNode) {
        super(Sense.dataFlavor, dataNode, null);
    }

    @Override
    protected void performAction(Transferable tr) throws UnsupportedFlavorException, IOException {
        // get new sense
        Sense sense = (Sense) tr.getTransferData(dataFlavor);
        if (sense == null) {
            return;
        }

        // get parent
        PoshElement parent = dataNode.getParent();
        if (parent == null) {
            return;
        }

        // Add new sense
        if (parent instanceof CompetenceElement) {
            CompetenceElement compAtom = (CompetenceElement) parent;
            compAtom.addUserTrigger(sense);

        } else if (parent instanceof Goal) {
            Goal goal = (Goal) parent;
            goal.addUserSense(sense);

        } else if (parent instanceof Triggers) {
            Triggers triggers = (Triggers) parent;
            triggers.addUserTrigger(sense);

        }
        // find out index, where is newly added sense
        int newlyAddedSenseIndex =
                this.getIndexInList(parent.getChildDataNodes(), sense);

        // find index, where should dropped sense be =
        //    index of sense new sense was dropped on
        int assignedSenseIndex =
                this.getIndexInList(parent.getChildDataNodes(), dataNode);

        int relativePositionChange = assignedSenseIndex - newlyAddedSenseIndex;
        if (relativePositionChange != 0) {
            parent.moveChild(sense, relativePositionChange);
        }
    }
}

==> posh-nb-support-3.3.0-20120309.081331-5-sources.jar: cz/cuni/pogamut/posh/widget/accept/AcceptSense2Sense.java <==
package cz.cuni.pogamut.posh.widget.accept;

import cz.cuni.amis.pogamut.sposh.elements.CompetenceElement;
import cz.cuni.amis.pogamut.sposh.elements.Goal;
import cz.cuni.amis.pogamut.sposh.elements.PoshElement;
import cz.cuni.amis.pogamut.sposh.elements.Sense;
import cz.cuni.amis.pogamut.sposh.elements.Triggers;

/**
 * When sense is dropped on the sense, add it to the list on the place
 * where passed poshsense was and move the rest of list down.
 * @author Honza
 */
public class AcceptSense2Sense extends AbstractAcceptAction<Sense, Sense> {

    public AcceptSense2Sense(Sense dataNode) {
        super(Sense.dataFlavor, dataNode, null);
    }

    @Override
    protected void performAction(Sense sense) {
        // get parent
        PoshElement parent = dataNode.getParent();
        if (parent == null) {
            return;
        }

        // Add new sense
        if (parent instanceof CompetenceElement) {
            CompetenceElement compAtom = (CompetenceElement) parent;
            compAtom.addUserTrigger(sense);

        } else if (parent instanceof Goal) {
            Goal goal = (Goal) parent;
            goal.addUserSense(sense);

        } else if (parent instanceof Triggers) {
            Triggers triggers = (Triggers) parent;
            triggers.addUserTrigger(sense);

        }
        // find out index, where is newly added sense
        int newlyAddedSenseIndex =
                this.getIndexInList(parent.getChildDataNodes(), sense);

        // find index, where should dropped sense be =
        //    index of sense new sense was dropped on
        int assignedSenseIndex =
                this.getIndexInList(parent.getChildDataNodes(), dataNode);

        int relativePositionChange = assignedSenseIndex - newlyAddedSenseIndex;
        if (relativePositionChange != 0) {
            parent.moveChild(sense, relativePositionChange);
        }
    }
}
